from setuptools import setup, find_packages

setup(
    name='musictool',
    version='1.0.1',
    description='set of tools to help learning scales, modes, modulations, chord progressions, voice leading, rhythm',
    long_description_content_type="text/markdown",
    url='https://github.com/tandav/musictool',
    # packages=find_packages(),
    py_modules=['musictool'],
)
